# tests/test_finance_data.py

from hn_data_stock import get_stock_data

def test_get_stock_data():
    data = get_stock_data('AAPL')  # Ví dụ sử dụng mã cổ phiếu của Apple
    assert data is not None
    # Thêm các assertions kiểm tra cấu trúc dữ liệu nhận được



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='HNDataStock',
    version='0.1.5',
    author='Hướng Nghiệp Dữ Liệu',
    author_email='daotao@huongnghiepdulieu.com',
    description='Trường đào tạo lập trình Forex, Crypto, Chứng Khoán',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='http://www.huongnghiepdulieu.com',
    packages=find_packages(),
    install_requires=[
        'requests',
        'yfinance'
    ],
   classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: Vietnamese',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: MIT License',
    ],
)



# hn_data_stock/finance_data.py

import requests
import yfinance as yf

def get_stock_data(ticker):

    # Lấy dữ liệu cổ phiếu Apple
    history = yf.Ticker(ticker)
    # Lấy dữ liệu giá trong vòng period tháng gần nhất
    history_data = history.history(period='1mo')
    
    return history_data